# Custom Content Types in Municipio

Municipio enhances your WordPress site with custom content types designed specifically for municipal and public sector websites. These content types facilitate the organization and presentation of content such as schools, events, places, projects, and more, leveraging structured schema data according to schema.org standards.

## Available Content Types

Municipio offers several custom content types out of the box:

- **Place**: Ideal for locations, landmarks, and points of interest.
- **Person**: For profiles of individuals, such as staff or public figures.
- **School**: Tailored for educational institutions.
- **Event**: For detailing upcoming or past events.
- **Project**: Suitable for showcasing ongoing or completed projects.

Each content type is equipped with a unique set of meta data fields, enabling the input of specific information to generate comprehensive schema.org data.

## Creating Content

Creating content with these custom content types follows the familiar process within the WordPress admin dashboard:

1. **Opt-In**: First, opt into a content type for your desired post type via the Customizer. This is a one-time setup.
2. **Create Post**: Navigate to the post creation area in the WordPress admin. The process remains standard, but you'll notice an additional ACF field group titled "schema.org data" for the relevant post type.
3. **Fill in Details**: Complete the fields under the "schema.org data" group as exhaustively and accurately as possible to enhance the SEO and structured data of your post.

## Displaying Content

Posts with custom content types *can* utilize specially designed templates for single and archive views, similar to WordPress's default template hierarchy. When setting up a content type in the Customizer, you have the option to use or not use these specialized templates, providing flexibility in content presentation.

## Common Use Cases

- **School Websites**: The 'School' content type allows for detailed presentation of school-related information, making it invaluable for educational institution websites.
- **Places Directory**: With the 'Place' content type, creating a directory of locations is streamlined, offering comprehensive information including addresses, which can be enhanced with Google Maps integration.

## Integration and Best Practices

- **Seamless Integration**: The custom content types are designed to work seamlessly with existing Municipio theme and WordPress features, without altering built-in functionalities.
- **Data Accuracy**: Ensure the information provided in the schema.org fields is accurate and detailed to maximize the SEO benefits.
- **Stay Updated**: Given the early development stage of this functionality, keep an eye out for updates and new features that can further enhance your site's content presentation and organization.

## Support and Community

The custom content type functionality is in continuous development, with new features and improvements being added regularly. While no significant issues have been reported, users are encouraged to stay updated with the latest releases and participate in the community for support and feedback.

For further assistance, the Municipio theme has a dedicated Slack community for both editors and developers. Join the conversation at [Municipio Slack Community](https://municipio-se.slack.com/).

